
#line 3 "giscanner/scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 170
#define YY_END_OF_BUFFER 171
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[1128] =
    {   0,
      171,  169,  170,    3,  169,  170,    1,  170,   45,  169,
      170,  169,  170,   20,  169,  170,   40,  169,  170,   42,
      169,  170,  169,  170,   29,  169,  170,   30,  169,  170,
       38,  169,  170,   36,  169,  170,   69,  169,  170,   37,
      169,  170,   35,  169,  170,   39,  169,  170,  162,  169,
      170,  162,  169,  170,   32,  169,  170,   31,  169,  170,
       47,  169,  170,   46,  169,  170,   48,  169,  170,   34,
      169,  170,  109,  159,  169,  170,  109,  159,  169,  170,
      109,  159,  169,  170,  109,  159,  169,  170,  109,  159,
      169,  170,   25,  169,  170,  169,  170,   27,  169,  170,

       41,  169,  170,  109,  159,  169,  170,  109,  159,  169,
      170,  109,  159,  169,  170,  109,  159,  169,  170,  109,
      159,  169,  170,  109,  159,  169,  170,  109,  159,  169,
      170,  109,  159,  169,  170,  109,  159,  169,  170,  109,
      159,  169,  170,  109,  159,  169,  170,  109,  159,  169,
      170,  109,  159,  169,  170,  109,  159,  169,  170,  109,
      159,  169,  170,  109,  159,  169,  170,   21,  169,  170,
       43,  169,  170,   23,  169,  170,   44,  169,  170,    3,
        1,   62,  167,   53,   24,   65,   55,  165,   51,   67,
       49,   68,   50,   70,  163,    4,    6,   52,  163,  161,

      162,  162,  162,  162,   28,   22,   26,   57,   63,   61,
       64,   58,  109,  159,  109,  159,  109,  159,  109,  159,
        2,   54,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  118,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  133,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,   56,   66,   33,  163,    6,  161,  162,  161,

      162,  164,  162,  162,  162,  160,   59,   60,  109,  159,
      109,  159,  168,  166,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  110,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      131,  159,  109,  159,  109,  159,  109,  135,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,

      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  163,  161,  162,  161,  162,
      161,  162,  164,  162,  160,  160,  109,  159,  109,  159,
      109,  159,  105,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      111,  159,  109,  159,  109,  113,  159,  109,  114,  159,

      109,  159,  109,  159,  109,  159,  109,  159,  109,  120,
      159,  109,  121,  159,  109,  159,  109,  159,  109,  159,
      109,  132,  159,  109,  159,  109,  141,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  107,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  156,  159,
      109,  159,  109,  159,   18,   13,  161,  162,  160,  160,
      160,  106,  109,  159,  109,  159,  109,  159,   96,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      159,   74,  109,  159,  109,  159,  109,  159,  109,  159,

      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  102,  109,  159,  109,  112,  159,
      109,  115,  159,  109,  159,  109,  159,  109,  159,  109,
      159,  108,  109,  159,  109,  123,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  145,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  154,  159,  109,  159,  109,  159,  109,
      158,  159,   15,  160,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,

      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  119,
      159,  109,  122,  159,  109,  134,  159,  109,  159,  109,
      159,  109,  144,  159,  109,  146,  159,  109,  149,  159,
      109,  150,  159,  109,  151,  159,  109,  152,  159,  109,
      159,  109,  159,  109,  159,  109,  159,   14,   16,    5,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,

       75,  109,  159,  109,  159,   98,  109,  159,   78,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,  109,
      136,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  117,  159,  109,  159,  109,  159,  109,  159,  109,
      153,  159,  109,  159,  109,  159,   12,  109,  159,  109,
      159,  109,  159,  109,  124,  159,  109,  125,  159,  109,
      126,  159,   83,  109,  159,  109,  159,  109,  159,  109,
      159,  109,  159,  109,  159,  109,  159,  109,  159,   81,
      109,  159,  109,  140,  159,  109,  159,   87,  109,  159,

      109,  159,  109,  147,  159,  109,  159,   93,  109,  159,
      109,  159,  109,  159,  109,  116,  159,  109,  142,  159,
      109,  143,  159,  109,  159,  109,  155,  159,  109,  157,
      159,    8,   11,   19,   17,  109,  159,  109,  159,  109,
      127,  159,  109,  128,  159,  109,  129,  159,   86,  109,
      159,  109,  159,   84,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,   82,  109,
      159,  109,  159,  109,  159,  101,  109,  159,  109,  159,
      109,  139,  159,  109,  159,  109,  159,    7,    8,  109,
      159,  109,  159,  109,  130,  159,  109,  159,  109,  159,

      109,  159,  109,  159,  109,  159,   80,  109,  159,  109,
      138,  159,   88,  109,  159,  109,  148,  159,   92,  109,
      159,  109,  159,   94,  109,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,   77,  109,  159,  109,
      159,  109,  159,  109,  137,  159,  109,  159,  109,  159,
      109,  159,  109,  159,  109,  159,  109,  159,  109,  159,
      109,  159,   89,  109,  159,   95,  109,  159,   90,  109,
      159,  109,  159,  109,  159,  109,  159,   91,  109,  159,
       76,  109,  159,  100,   79,  109,  159,  109,  159,  109,
      159,  109,  159,   71,  109,  159,  109,  159,  109,  159,

      109,  159,  109,  159,  109,  159,   72,  103,  109,  159,
      109,  159,   85,  109,  159,  104,  109,  159,   73,    9,
        9,   12,   10,   10,   11,   99,   97
    } ;

static const flex_int16_t yy_accept[746] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   85,   89,   93,   96,   98,  101,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  160,  164,  168,  171,  174,  177,  180,  181,  182,
      183,  183,  184,  184,  184,  184,  184,  184,  184,  184,
      185,  186,  187,  188,  188,  189,  189,  190,  191,  192,
      193,  194,  195,  195,  196,  197,  198,  199,  200,  202,
      203,  203,  204,  205,  205,  206,  207,  208,  209,  210,

      211,  212,  213,  215,  217,  219,  219,  219,  221,  222,
      223,  225,  227,  229,  231,  233,  235,  237,  239,  241,
      243,  245,  247,  250,  252,  254,  256,  258,  260,  262,
      264,  267,  269,  271,  273,  275,  277,  279,  281,  283,
      285,  287,  289,  291,  293,  294,  295,  295,  295,  295,
      295,  295,  295,  295,  296,  296,  297,  297,  297,  298,
      300,  302,  302,  303,  304,  305,  306,  307,  308,  309,
      311,  313,  313,  314,  314,  314,  315,  315,  317,  319,
      321,  323,  325,  327,  329,  331,  333,  335,  337,  339,
      341,  343,  345,  347,  349,  351,  353,  356,  358,  360,

      362,  364,  366,  368,  370,  372,  374,  376,  378,  380,
      383,  385,  387,  390,  392,  394,  396,  398,  400,  402,
      404,  406,  408,  410,  412,  414,  416,  418,  420,  422,
      424,  426,  426,  426,  426,  426,  426,  426,  426,  426,
      426,  426,  426,  427,  427,  429,  431,  433,  434,  435,
      436,  437,  439,  441,  443,  446,  448,  450,  452,  454,
      456,  458,  460,  462,  464,  466,  468,  470,  472,  474,
      476,  478,  480,  482,  484,  486,  488,  490,  493,  495,
      498,  501,  503,  505,  507,  509,  512,  515,  517,  519,
      521,  524,  526,  529,  531,  533,  535,  537,  539,  541,

      543,  545,  547,  549,  552,  554,  556,  558,  561,  563,
      565,  565,  566,  566,  566,  566,  566,  566,  567,  567,
      567,  567,  567,  567,  569,  570,  571,  572,  575,  577,
      579,  582,  584,  586,  588,  590,  592,  595,  597,  599,
      601,  603,  605,  607,  609,  611,  613,  615,  617,  619,
      621,  623,  625,  628,  631,  634,  636,  638,  640,  642,
      645,  648,  650,  652,  654,  656,  659,  661,  663,  665,
      667,  669,  671,  673,  676,  678,  680,  683,  683,  683,
      683,  684,  684,  684,  684,  684,  684,  684,  684,  685,
      687,  689,  691,  693,  695,  697,  699,  701,  701,  703,

      705,  707,  709,  711,  713,  715,  717,  719,  721,  723,
      725,  727,  729,  731,  733,  735,  737,  739,  742,  745,
      748,  750,  752,  755,  758,  761,  764,  767,  770,  772,
      774,  776,  778,  778,  778,  779,  779,  780,  780,  780,
      780,  780,  780,  781,  783,  785,  787,  789,  791,  793,
      795,  797,  799,  801,  801,  804,  806,  809,  812,  814,
      816,  818,  820,  823,  825,  827,  829,  831,  833,  835,
      837,  839,  841,  844,  846,  848,  850,  853,  855,  857,
      857,  857,  857,  857,  858,  858,  858,  858,  858,  858,
      860,  862,  864,  867,  870,  873,  876,  878,  880,  882,

      884,  884,  884,  886,  888,  890,  893,  896,  898,  901,
      903,  906,  908,  911,  913,  915,  918,  921,  924,  926,
      926,  929,  932,  933,  933,  933,  933,  933,  933,  934,
      934,  934,  935,  935,  936,  938,  940,  943,  946,  949,
      952,  954,  957,  959,  959,  959,  959,  961,  963,  965,
      967,  969,  972,  974,  976,  979,  981,  984,  986,  988,
      988,  989,  990,  990,  990,  990,  990,  992,  994,  997,
      999, 1001, 1001, 1001, 1001, 1003, 1005, 1007, 1010, 1013,
     1016, 1019, 1022, 1024, 1027, 1029, 1029, 1029, 1029, 1029,
     1029, 1031, 1033, 1035, 1037, 1037, 1037, 1037, 1040, 1040,

     1040, 1042, 1044, 1047, 1049, 1051, 1051, 1051, 1051, 1051,
     1051, 1053, 1055, 1057, 1059, 1059, 1059, 1059, 1061, 1061,
     1061, 1061, 1063, 1066, 1069, 1072, 1072, 1072, 1072, 1072,
     1072, 1074, 1076, 1078, 1081, 1081, 1081, 1081, 1084, 1085,
     1085, 1088, 1088, 1088, 1088, 1088, 1088, 1090, 1092, 1094,
     1095, 1095, 1095, 1095, 1095, 1095, 1095, 1095, 1095, 1097,
     1099, 1101, 1101, 1101, 1101, 1101, 1101, 1101, 1101, 1101,
     1103, 1105, 1107, 1107, 1108, 1108, 1108, 1108, 1108, 1108,
     1108, 1111, 1113, 1116, 1116, 1116, 1116, 1116, 1116, 1116,
     1116, 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119,

     1119, 1119, 1119, 1119, 1119, 1119, 1120, 1120, 1120, 1120,
     1120, 1120, 1120, 1120, 1120, 1120, 1120, 1121, 1121, 1121,
     1123, 1123, 1123, 1123, 1123, 1123, 1123, 1124, 1124, 1124,
     1126, 1126, 1126, 1126, 1127, 1127, 1127, 1127, 1127, 1127,
     1127, 1127, 1127, 1128, 1128
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   26,   25,   27,   28,   29,   30,   31,
       32,   33,   34,    1,   35,   36,   37,   38,   39,   40,
       41,   42,   43,   42,   42,   44,   42,   45,   46,   42,
       42,   47,   48,   49,   50,   42,   42,   51,   42,   42,
       52,   53,   54,   55,   56,    1,   57,   58,   59,   60,

       61,   62,   63,   64,   65,   66,   67,   68,   69,   70,
       71,   72,   66,   73,   74,   75,   76,   77,   78,   79,
       80,   81,   82,   83,   84,   85,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[86] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    5,    1,    1,    1,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    1,    1,
        1,    5,    1,    1,    7,    7,    7,    7,    8,    9,
       10,   10,   10,   11,   10,   10,   10,   10,   10,   10,
       10,    1,    1,    1,    1,   10,   12,   12,   12,   12,
       13,   14,   15,   15,   15,   15,   15,   16,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[775] =
    {   0,
        0,    0, 1409, 1410,   84,    0, 1376,   80,   85,   59,
       83,   83, 1410, 1410, 1375,   80, 1410,   81,   79,   97,
      140,  202, 1373, 1410,   99, 1373,   77, 1410,    0, 1369,
     1347,  110, 1355, 1410, 1398, 1410, 1368,   98,   44, 1326,
       68,   66,   56,   84, 1327,   78, 1326, 1335,  105,  108,
     1325, 1323, 1329, 1410,   90, 1410, 1410,  172,    0, 1410,
       89, 1410, 1389,  172, 1330,   81, 1328, 1324, 1315, 1410,
     1410, 1410, 1410,  133, 1410, 1384, 1410, 1410, 1410, 1410,
     1410, 1410, 1368,  170,  154,    0, 1410,  196,  193,    0,
      259,  171,  134,    0, 1410, 1410, 1410, 1353, 1410, 1410,

     1410, 1352,    0, 1339, 1341,  164,  192, 1331, 1410, 1410,
     1309, 1311,  111, 1314,  231, 1308, 1301, 1314, 1300, 1316,
     1302, 1309, 1294, 1295, 1292, 1292, 1298, 1294, 1291, 1288,
        0,  136, 1292,  179, 1290,  126,  161, 1295, 1286, 1282,
     1285,  185,  183, 1291, 1410, 1410,  290, 1293,  191, 1294,
      207, 1283, 1295, 1410,  304, 1410, 1320,    0,    0,  289,
      205,  320,  231,  218, 1410,  254,  305, 1410, 1410, 1302,
      163,  282, 1410, 1346,  244, 1410, 1345, 1308, 1275, 1274,
      250, 1276, 1270,  262,  290, 1281, 1262, 1270, 1268, 1265,
     1276,  287, 1256, 1270, 1263, 1307,    0, 1261, 1274, 1269,

     1256,  279, 1271, 1269, 1265, 1256, 1263, 1249, 1265,    0,
     1250, 1255,    0, 1256, 1253, 1242, 1240, 1242, 1244, 1252,
     1237, 1235, 1235, 1248, 1247, 1246, 1235, 1240, 1244, 1246,
     1234, 1298, 1235, 1237, 1237, 1232, 1293, 1234, 1234, 1232,
     1229,  362,  330, 1258,  284, 1410,  307, 1410, 1410,  327,
      312, 1251, 1244, 1245,    0, 1219, 1229, 1215, 1223, 1215,
     1221, 1212, 1205, 1218, 1208, 1218, 1201,  291, 1205, 1217,
     1199, 1209, 1211, 1198, 1199, 1200, 1243,    0, 1199,    0,
        0, 1190, 1199, 1187, 1194,    0,    0, 1188, 1199, 1184,
        0, 1188,    0, 1183, 1183, 1182, 1179, 1192, 1181, 1186,

     1191, 1190, 1191,    0, 1187, 1176, 1182,    0, 1169, 1182,
     1239, 1410, 1171, 1235, 1236, 1176, 1234, 1410, 1174, 1174,
     1229, 1164,  362, 1410,  318, 1410,  325,    0, 1183, 1186,
        0, 1155, 1153, 1153,  322, 1170,  395, 1153, 1166, 1150,
     1155, 1161, 1156,  337, 1150, 1156, 1143, 1147, 1157, 1154,
     1139, 1156,    0,    0,    0, 1142, 1143, 1149, 1139,    0,
        0, 1147, 1132, 1141, 1135,    0, 1144, 1141, 1143, 1126,
     1136, 1139, 1137,    0, 1127, 1131,    0, 1134, 1191, 1190,
     1410, 1189,  399, 1129,  385, 1133, 1175, 1169, 1410, 1161,
     1137,  393, 1117, 1108, 1107, 1124, 1121,  413, 1124, 1114,

     1110, 1102, 1102, 1105, 1104, 1151, 1148, 1095, 1101, 1096,
     1107, 1110, 1095, 1144, 1089, 1087, 1087,    0,    0,    0,
     1100, 1101,    0,    0,    0,    0,    0,    0, 1103, 1096,
     1096, 1088, 1150, 1151, 1410, 1150, 1410,  418,  419,  423,
      421, 1147, 1410, 1127, 1124,   97, 1127, 1124, 1079, 1073,
     1075, 1076, 1087, 1071,  425, 1083,    0,    0, 1068, 1065,
     1077, 1110,    0, 1068, 1078, 1069, 1073, 1064, 1069, 1108,
     1064, 1067,    0, 1054, 1051, 1057, 1119, 1063, 1061,    0,
     1065, 1117,  429, 1410,  335,  431,  435, 1116, 1115, 1061,
     1092, 1088,    0, 1035, 1034,    0, 1042, 1037, 1049, 1041,

     1040,  448, 1031, 1045, 1040, 1048, 1047, 1034,    0, 1042,
     1044, 1031, 1042, 1070, 1028,    0,    0,    0, 1024, 1035,
        0,    0, 1081, 1051,  259, 1035, 1087,  452, 1410,  432,
     1086, 1410, 1085, 1410, 1050, 1030, 1006,    0,    0,    0,
     1012,    0, 1012, 1025, 1025, 1009, 1004, 1019, 1006, 1020,
     1000,    0,  999, 1017,    0, 1016, 1015, 1009, 1010, 1004,
     1410, 1055, 1023,  436, 1024,  453, 1018, 1026,    0, 1001,
     1002,  985,  982,  990,  996,  456,  986,    0,    0,  999,
        0,    0,  979,  997,  995,  994,  994,  456, 1006,  457,
     1003, 1001,  987,  988,  979,  972,  985,  985,  460,  980,

      983,  982,    0,  981,  968,  962,  986,  461,  977,  460,
      984,  986,  965,  961,  960,  959,  951,  969,    0, 1011,
      453,  967,    0,    0,    0, 1017,  984,  464,  972,  467,
      970,  970,  955,    0,  955,  958,  949,    0, 1410,  456,
        0,  957,  977,  468,  974,  470,  975,  960,  943, 1410,
      932,  938,  463,  949,  930,  257,  868,  475,  857,  866,
      839,  834,  837,  468,  823,  851,  474,  850,  477,  833,
      712,  695,  686, 1410,  471,  677,  711,  479,  704,  486,
        0,  665,    0,  651,  470,  654,  662,  490,  668,  493,
        0,  650,  473,  617,  635,  489,  607,  492,  597,  485,

      570,  575,  494,  572,  496, 1410,  489,  567,  518,  538,
      567,  502,  521,  509,  558,  554, 1410,  552,  548, 1410,
      551,  557,  534,  487,  539,  535, 1410,  532,  523, 1410,
      511,  504,  439,  498,  432,  341,  323,  297,  210,  158,
      202,  172, 1410, 1410,  562,  578,  594,  605,  616,  632,
      643,  657,  673,  688,  699,  715,  731,  742,  758,  774,
      790,  806,  816,  832,  848,  864,  877,  892,  908,  924,
      940,  956,  972,  988
    } ;

static const flex_int16_t yy_def[775] =
    {   0,
      744,    1,  744,  744,  744,  745,  744,  746,  744,  744,
      744,  747,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  748,  748,
      748,  748,  748,  744,  744,  744,  744,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  744,  744,  744,  744,  744,  745,  744,
      746,  744,  746,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  747,  744,  747,  744,  744,  744,  744,
      744,  744,  744,  749,  744,  750,  744,  749,   21,   22,
      744,  744,  744,  751,  744,  744,  744,  744,  744,  744,

      744,  744,  748,  748,  748,  752,  753,  748,  744,  744,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  754,  750,  744,
      744,  744,  755,  744,  744,  744,  751,  744,  744,  748,
      748,  752,  744,  752,  753,  744,  753,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,

      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  756,  744,  744,  744,  744,  757,  744,  744,  744,
      744,  744,  758,  754,  744,  744,  744,  744,  744,  744,
      744,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,

      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      756,  744,  744,  744,  759,  744,  757,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  744,  760,  759,
      744,  761,  744,  744,  744,  744,  744,  744,  744,  748,
      748,  748,  748,  748,  748,  748,  748,  744,  748,  748,

      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  744,  760,  744,  761,  744,  744,  762,  744,
      744,  744,  744,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  744,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  763,
      744,  762,  762,  744,  762,  744,  764,  765,  766,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,

      744,  744,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  744,
      748,  748,  767,  744,  762,  744,  764,  764,  744,  764,
      765,  744,  766,  744,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  744,  744,  744,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  744,
      744,  767,  744,  762,  744,  764,  748,  748,  748,  748,
      748,  744,  744,  744,  748,  748,  748,  748,  748,  748,
      748,  748,  748,  748,  748,  744,  744,  762,  744,  764,
      748,  748,  748,  748,  744,  744,  744,  748,  744,  768,

      748,  748,  748,  748,  748,  744,  744,  762,  744,  764,
      748,  748,  748,  748,  744,  744,  744,  748,  768,  768,
      768,  748,  748,  748,  748,  744,  744,  762,  744,  764,
      748,  748,  748,  748,  744,  744,  744,  748,  744,  768,
      748,  744,  744,  762,  744,  764,  748,  748,  748,  744,
      744,  744,  768,  744,  744,  762,  744,  764,  748,  748,
      748,  744,  744,  768,  744,  744,  762,  744,  764,  748,
      748,  748,  744,  744,  768,  744,  744,  762,  744,  764,
      748,  748,  748,  744,  768,  744,  744,  762,  744,  764,
      748,  744,  768,  744,  744,  762,  744,  764,  744,  768,

      744,  744,  762,  744,  764,  744,  768,  744,  769,  770,
      744,  764,  768,  744,  769,  769,  744,  770,  770,  744,
      771,  772,  773,  744,  771,  771,  744,  772,  772,  744,
      773,  773,  744,  773,  744,  744,  744,  744,  744,  744,
      774,  774,  744,    0,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744
    } ;

static const flex_int16_t yy_nxt[1496] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   22,   23,   24,
       25,   26,   27,   28,   29,   29,   29,   29,   29,   30,
       31,   29,   29,   32,   29,   29,   29,   29,   33,   29,
       29,   34,   35,   36,   37,   38,   39,   40,   41,   42,
       43,   44,   45,   29,   46,   29,   29,   47,   29,   29,
       29,   29,   48,   49,   50,   51,   52,   53,   29,   29,
       29,   54,   55,   56,   57,   58,   62,   58,   58,   64,
       70,   71,   72,   75,   78,   62,   83,   80,   84,   84,

       84,   84,   84,   84,   84,   84,   84,   96,  101,  102,
       85,   79,   81,   82,   73,   86,  106,  116,  492,  117,
      107,  145,  493,  124,  119,  125,  122,   97,   87,   98,
       99,  120,   63,  111,  126,   76,  123,  112,  121,  131,
      127,   63,  113,   75,   65,   66,  114,  132,  149,   67,
      150,  128,   68,  115,  129,  157,   69,   88,  157,   89,
       89,   89,   89,   89,   89,   89,   90,   90,  135,  136,
      173,  139,  146,   58,  743,   58,   58,  166,   91,  137,
      140,  181,  138,   92,  158,   76,  182,  141,  219,   93,
       94,  147,  147,  147,  147,  147,  147,  147,  147,  147,

       91,  166,  176,  212,  743,  253,  220,   92,  155,  156,
      213,  237,  254,  156,  164,   93,  174,  221,   94,   88,
      165,   90,   90,   90,   90,   90,   90,   90,   90,   90,
      155,  156,  741,  222,  155,  156,  160,  156,  164,  156,
       91,  215,  161,  744,  177,   92,  165,  229,  247,  227,
      230,   93,  216,  217,  176,  234,  155,  156,  228,  484,
      160,  484,   91,  156,  235,  740,  238,  165,  161,   92,
      248,  744,  247,  162,  248,  162,  239,   93,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  184,  173,  185,
      186,  187,  248,  165,  232,  188,  177,  249,  248,  564,

      189,  667,  190,  191,  192,  193,  194,  195,  196,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  242,  258,
      242,  249,  259,  243,  243,  243,  243,  243,  243,  243,
      243,  243,  245,  246,  174,  262,  263,  484,  246,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  250,  264,
      324,  272,  282,  283,  251,  327,  245,  406,  343,  246,
      265,  273,  407,  387,  246,  344,  387,  326,  389,  156,
      325,  739,  250,  156,  324,  388,  326,  395,  396,  327,
      251,  243,  243,  243,  243,  243,  243,  243,  243,  243,
      525,  156,  389,  326,  325,  738,  398,  156,  398,  398,

      438,  737,  326,  439,  441,  441,  441,  441,  441,  441,
      441,  441,  441,  446,  398,  447,  398,  398,  448,  438,
      483,  484,  438,  483,  486,  488,  502,  487,  502,  502,
      483,  484,  486,  483,  529,  486,  528,  529,  484,  528,
      441,  441,  441,  441,  441,  441,  441,  441,  441,  502,
      399,  502,  502,  528,  529,  529,  528,  599,  484,  529,
      599,  599,  529,  484,  599,  639,  484,  600,  639,  529,
      484,  619,  529,  481,  485,  639,  484,  529,  588,  529,
      639,  484,  639,  639,  485,  639,  526,  566,  529,  454,
      530,  484,  484,  590,  529,  529,  484,  639,  529,  610,

      644,  639,  656,  545,  529,  736,  658,  530,  628,  669,
      734,  608,  735,  640,  646,  630,  734,  688,  678,  716,
      717,  680,  716,  732,  546,  730,  693,  653,  675,  685,
      690,  698,  723,  639,  730,  664,  696,  727,  705,  719,
      720,  727,  719,  733,  703,  707,  732,  700,  713,  710,
      720,  712,  726,  727,  720,  726,  717,  722,  729,  730,
      717,  729,   59,   59,  724,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   74,   74,   74,   74,   74,   74,

       74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,   84,  721,   84,   84,  714,   84,  711,   84,   84,
      709,   84,  159,  159,  708,  159,  159,  159,  159,  159,
      159,  159,  159,  159,  159,  159,  159,  159,  167,  167,
      167,  167,  706,  704,  167,  167,  167,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  175,  175,  175,  175,  175,  175,  175,
      175,  175,  175,  175,  175,  175,  175,  175,  175,  244,
      702,  701,  244,  244,  244,  244,  244,  244,  244,  244,

      244,  244,  244,  244,  163,  699,  697,  163,  695,  163,
      694,  692,  163,  691,  163,  311,  311,  311,  311,  311,
      311,  311,  311,  311,  311,  311,  311,  311,  311,  311,
      311,  317,  317,  317,  317,  317,  317,  317,  317,  317,
      317,  317,  317,  317,  317,  317,  317,  243,  689,  687,
      243,  686,  243,  684,  683,  243,  682,  243,  380,  380,
      380,  380,  380,  380,  380,  380,  380,  380,  380,  380,
      380,  380,  380,  380,  434,  434,  434,  434,  434,  434,
      434,  434,  434,  434,  434,  434,  434,  434,  434,  434,
      436,  436,  436,  436,  436,  436,  436,  436,  436,  436,

      436,  436,  436,  436,  436,  436,  482,  482,  482,  482,
      482,  482,  482,  482,  482,  482,  482,  482,  482,  482,
      482,  482,  523,  523,  523,  523,  523,  523,  523,  523,
      523,  523,  527,  527,  527,  527,  527,  527,  527,  527,
      527,  527,  527,  527,  527,  527,  527,  527,  531,  531,
      531,  531,  531,  531,  531,  531,  531,  531,  531,  531,
      531,  531,  531,  531,  533,  533,  533,  533,  533,  533,
      533,  533,  533,  533,  533,  533,  533,  533,  533,  533,
      562,  681,  562,  562,  562,  562,  562,  562,  562,  562,
      562,  562,  562,  620,  679,  677,  676,  674,  673,  672,

      671,  670,  668,  620,  620,  620,  620,  620,  715,  715,
      715,  715,  715,  715,  715,  715,  715,  715,  715,  715,
      715,  715,  715,  715,  718,  718,  718,  718,  718,  718,
      718,  718,  718,  718,  718,  718,  718,  718,  718,  718,
      725,  725,  725,  725,  725,  725,  725,  725,  725,  725,
      725,  725,  725,  725,  725,  725,  728,  728,  728,  728,
      728,  728,  728,  728,  728,  728,  728,  728,  728,  728,
      728,  728,  731,  731,  666,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  742,  742,
      742,  742,  742,  742,  742,  742,  742,  742,  742,  742,

      742,  742,  742,  742,  665,  663,  662,  661,  660,  659,
      657,  655,  654,  652,  651,  650,  649,  648,  647,  645,
      643,  642,  641,  639,  638,  637,  636,  635,  634,  633,
      632,  631,  629,  627,  626,  625,  624,  623,  622,  621,
      618,  617,  616,  615,  614,  613,  612,  611,  609,  607,
      606,  605,  604,  603,  602,  601,  598,  597,  596,  595,
      594,  593,  592,  591,  589,  587,  561,  586,  585,  584,
      583,  582,  581,  580,  579,  578,  577,  576,  575,  574,
      573,  572,  571,  570,  569,  568,  567,  534,  532,  529,
      565,  563,  561,  560,  559,  558,  557,  556,  555,  554,

      553,  552,  551,  550,  549,  548,  547,  544,  543,  542,
      541,  540,  539,  538,  537,  536,  535,  534,  532,  484,
      524,  522,  521,  520,  519,  518,  517,  516,  515,  514,
      513,  512,  511,  510,  509,  508,  507,  506,  505,  504,
      503,  501,  500,  499,  498,  497,  496,  495,  494,  491,
      490,  489,  437,  435,  480,  479,  478,  477,  476,  475,
      474,  473,  472,  471,  470,  469,  468,  467,  466,  465,
      464,  463,  462,  461,  460,  459,  458,  457,  456,  455,
      453,  452,  451,  450,  449,  445,  444,  443,  388,  442,
      440,  437,  381,  435,  433,  432,  431,  430,  429,  428,

      427,  426,  425,  424,  423,  422,  421,  420,  419,  418,
      417,  416,  415,  414,  413,  412,  411,  410,  409,  408,
      405,  404,  403,  402,  401,  400,  397,  394,  393,  392,
      391,  390,  386,  385,  384,  383,  318,  382,  381,  379,
      378,  312,  377,  376,  375,  374,  373,  372,  371,  370,
      369,  368,  367,  366,  365,  364,  363,  362,  361,  360,
      359,  358,  357,  356,  355,  354,  353,  352,  351,  350,
      349,  348,  347,  346,  345,  342,  341,  340,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  329,  328,
      323,  322,  321,  320,  319,  318,  316,  315,  314,  313,

      312,  310,  309,  308,  307,  306,  305,  304,  303,  302,
      301,  300,  299,  298,  297,  296,  295,  294,  293,  292,
      291,  290,  289,  288,  287,  286,  285,  284,  281,  280,
      279,  278,  277,  276,  275,  274,  271,  270,  269,  268,
      267,  266,  261,  260,  257,  256,  255,  744,  744,  252,
      158,  241,  240,  236,  233,  231,  226,  225,  224,  223,
      218,  214,  211,  210,  209,  208,  207,  206,  205,  204,
      203,  202,  201,  200,  199,  198,  197,  183,  180,  179,
      178,  171,  170,  169,  168,  154,  744,  153,  152,  151,
      148,  744,  144,  143,  142,  134,  133,  130,  118,  110,

      109,  108,  105,  104,  100,   95,   77,   60,  744,    3,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744

    } ;

static const flex_int16_t yy_chk[1496] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    5,    8,    5,    5,    9,
       10,   10,   11,   12,   16,   61,   19,   18,   19,   19,

       19,   19,   19,   19,   19,   19,   19,   25,   27,   27,
       20,   16,   18,   18,   11,   20,   32,   39,  446,   39,
       32,   55,  446,   43,   41,   43,   42,   25,   20,   25,
       25,   41,    8,   38,   43,   12,   42,   38,   41,   46,
       44,   61,   38,   74,    9,    9,   38,   46,   66,    9,
       66,   44,    9,   38,   44,   85,    9,   21,   85,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   49,   49,
      106,   50,   55,   58,  742,   58,   58,   93,   21,   49,
       50,  113,   49,   21,   85,   74,  113,   50,  136,   21,
       21,   64,   64,   64,   64,   64,   64,   64,   64,   64,

       21,   93,  107,  132,  741,  171,  136,   21,   84,   84,
      132,  151,  171,   84,   92,   21,  106,  137,   21,   22,
       92,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       84,   84,  740,  137,   88,   88,   89,   84,   92,   88,
       22,  134,   89,   89,  107,   22,   92,  143,  161,  142,
      143,   22,  134,  134,  175,  149,   88,   88,  142,  656,
       89,  525,   22,   88,  149,  739,  151,  164,   89,   22,
      163,   89,  161,   91,  163,   91,  151,   22,   91,   91,
       91,   91,   91,   91,   91,   91,   91,  115,  172,  115,
      115,  115,  163,  164,  147,  115,  175,  166,  163,  525,

      115,  656,  115,  115,  115,  115,  115,  115,  115,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  155,  181,
      155,  166,  181,  155,  155,  155,  155,  155,  155,  155,
      155,  155,  160,  245,  172,  184,  184,  485,  160,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  167,  185,
      247,  192,  202,  202,  167,  251,  160,  344,  268,  245,
      185,  192,  344,  323,  160,  268,  323,  325,  327,  243,
      250,  738,  167,  243,  247,  323,  250,  335,  335,  251,
      167,  242,  242,  242,  242,  242,  242,  242,  242,  242,
      485,  243,  327,  325,  250,  737,  337,  243,  337,  337,

      383,  736,  250,  383,  385,  385,  385,  385,  385,  385,
      385,  385,  385,  392,  398,  392,  398,  398,  392,  438,
      439,  439,  438,  439,  440,  441,  455,  440,  455,  455,
      483,  483,  486,  483,  530,  486,  487,  487,  564,  487,
      441,  441,  441,  441,  441,  441,  441,  441,  441,  502,
      337,  502,  502,  528,  528,  566,  528,  576,  588,  590,
      576,  599,  610,  608,  599,  621,  628,  576,  640,  630,
      644,  599,  646,  438,  439,  653,  667,  658,  564,  669,
      664,  678,  685,  675,  483,  693,  486,  530,  680,  398,
      487,  696,  688,  566,  698,  690,  703,  700,  705,  590,

      628,  707,  644,  502,  712,  735,  646,  528,  608,  658,
      734,  588,  733,  621,  630,  610,  732,  678,  667,  709,
      709,  669,  709,  731,  502,  729,  685,  640,  664,  675,
      680,  690,  713,  713,  728,  653,  688,  726,  698,  710,
      710,  725,  710,  724,  696,  700,  723,  693,  707,  703,
      719,  705,  721,  721,  718,  721,  716,  712,  722,  722,
      715,  722,  745,  745,  714,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  746,  746,
      746,  746,  746,  746,  746,  746,  746,  746,  746,  746,
      746,  746,  746,  746,  747,  747,  747,  747,  747,  747,

      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  748,
      748,  749,  711,  749,  749,  708,  749,  704,  749,  749,
      702,  749,  750,  750,  701,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  751,  751,
      751,  751,  699,  697,  751,  751,  751,  752,  752,  752,
      752,  752,  752,  752,  752,  752,  752,  752,  752,  752,
      752,  752,  752,  753,  753,  753,  753,  753,  753,  753,
      753,  753,  753,  753,  753,  753,  753,  753,  753,  754,
      695,  694,  754,  754,  754,  754,  754,  754,  754,  754,

      754,  754,  754,  754,  755,  692,  689,  755,  687,  755,
      686,  684,  755,  682,  755,  756,  756,  756,  756,  756,
      756,  756,  756,  756,  756,  756,  756,  756,  756,  756,
      756,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  758,  679,  677,
      758,  676,  758,  673,  672,  758,  671,  758,  759,  759,
      759,  759,  759,  759,  759,  759,  759,  759,  759,  759,
      759,  759,  759,  759,  760,  760,  760,  760,  760,  760,
      760,  760,  760,  760,  760,  760,  760,  760,  760,  760,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,

      761,  761,  761,  761,  761,  761,  762,  762,  762,  762,
      762,  762,  762,  762,  762,  762,  762,  762,  762,  762,
      762,  762,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  764,  764,  764,  764,  764,  764,  764,  764,
      764,  764,  764,  764,  764,  764,  764,  764,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  766,  766,  766,  766,  766,  766,
      766,  766,  766,  766,  766,  766,  766,  766,  766,  766,
      767,  670,  767,  767,  767,  767,  767,  767,  767,  767,
      767,  767,  767,  768,  668,  666,  665,  663,  662,  661,

      660,  659,  657,  768,  768,  768,  768,  768,  769,  769,
      769,  769,  769,  769,  769,  769,  769,  769,  769,  769,
      769,  769,  769,  769,  770,  770,  770,  770,  770,  770,
      770,  770,  770,  770,  770,  770,  770,  770,  770,  770,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  773,  773,  655,  773,  773,  773,  773,  773,
      773,  773,  773,  773,  773,  773,  773,  773,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,

      774,  774,  774,  774,  654,  652,  651,  649,  648,  647,
      645,  643,  642,  637,  636,  635,  633,  632,  631,  629,
      627,  626,  622,  620,  618,  617,  616,  615,  614,  613,
      612,  611,  609,  607,  606,  605,  604,  602,  601,  600,
      598,  597,  596,  595,  594,  593,  592,  591,  589,  587,
      586,  585,  584,  583,  580,  577,  575,  574,  573,  572,
      571,  570,  568,  567,  565,  563,  562,  560,  559,  558,
      557,  556,  554,  553,  551,  550,  549,  548,  547,  546,
      545,  544,  543,  541,  537,  536,  535,  533,  531,  527,
      526,  524,  523,  520,  519,  515,  514,  513,  512,  511,

      510,  508,  507,  506,  505,  504,  503,  501,  500,  499,
      498,  497,  495,  494,  492,  491,  490,  489,  488,  482,
      481,  479,  478,  477,  476,  475,  474,  472,  471,  470,
      469,  468,  467,  466,  465,  464,  462,  461,  460,  459,
      456,  454,  453,  452,  451,  450,  449,  448,  447,  445,
      444,  442,  436,  434,  433,  432,  431,  430,  429,  422,
      421,  417,  416,  415,  414,  413,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  403,  402,  401,  400,  399,
      397,  396,  395,  394,  393,  391,  390,  388,  387,  386,
      384,  382,  380,  379,  378,  376,  375,  373,  372,  371,

      370,  369,  368,  367,  365,  364,  363,  362,  359,  358,
      357,  356,  352,  351,  350,  349,  348,  347,  346,  345,
      343,  342,  341,  340,  339,  338,  336,  334,  333,  332,
      330,  329,  322,  321,  320,  319,  317,  316,  315,  314,
      313,  311,  310,  309,  307,  306,  305,  303,  302,  301,
      300,  299,  298,  297,  296,  295,  294,  292,  290,  289,
      288,  285,  284,  283,  282,  279,  277,  276,  275,  274,
      273,  272,  271,  270,  269,  267,  266,  265,  264,  263,
      262,  261,  260,  259,  258,  257,  256,  254,  253,  252,
      244,  241,  240,  239,  238,  237,  236,  235,  234,  233,

      232,  231,  230,  229,  228,  227,  226,  225,  224,  223,
      222,  221,  220,  219,  218,  217,  216,  215,  214,  212,
      211,  209,  208,  207,  206,  205,  204,  203,  201,  200,
      199,  198,  196,  195,  194,  193,  191,  190,  189,  188,
      187,  186,  183,  182,  180,  179,  178,  177,  174,  170,
      157,  153,  152,  150,  148,  144,  141,  140,  139,  138,
      135,  133,  130,  129,  128,  127,  126,  125,  124,  123,
      122,  121,  120,  119,  118,  117,  116,  114,  112,  111,
      108,  105,  104,  102,   98,   83,   76,   69,   68,   67,
       65,   63,   53,   52,   51,   48,   47,   45,   40,   37,

       35,   33,   31,   30,   26,   23,   15,    7,    3,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744

    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "giscanner/scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "giscanner/scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <string.h>
#ifndef _WIN32
#include <limits.h>
#endif

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner, gboolean has_line);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
static void print_error (GISourceScanner *scanner);

#if (YY_FLEX_MAJOR_VERSION > 2) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION > 6)) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION == 6) && (YY_FLEX_SUBMINOR_VERSION >= 1))
#define IS_EOF 0
#else
#define IS_EOF EOF
#endif

#line 1223 "giscanner/scannerlexer.c"
#line 1224 "giscanner/scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 78 "giscanner/scannerlexer.l"


#line 1448 "giscanner/scannerlexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 745 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1410 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];

find_rule: /* we branch to this label when backing up */

		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 80 "giscanner/scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 86 "giscanner/scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 88 "giscanner/scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 90 "giscanner/scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 91 "giscanner/scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 92 "giscanner/scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 94 "giscanner/scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 95 "giscanner/scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 96 "giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_GI_SCANNER; }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 97 "giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_GI_SCANNER; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 98 "giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_COND; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 99 "giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_COND; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 100 "giscanner/scannerlexer.l"
{ ++lineno; return IF_COND; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 101 "giscanner/scannerlexer.l"
{ ++lineno; return ELIF_COND; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 102 "giscanner/scannerlexer.l"
{ ++lineno; return ELSE_COND; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 103 "giscanner/scannerlexer.l"
{ ++lineno; return ENDIF_COND; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 104 "giscanner/scannerlexer.l"
{ ++lineno; /* Ignore pragma. */ }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 106 "giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, FALSE); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 107 "giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, TRUE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 108 "giscanner/scannerlexer.l"
{ }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 109 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 110 "giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 111 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 112 "giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 113 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 114 "giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 115 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 116 "giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 117 "giscanner/scannerlexer.l"
{ return '('; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 118 "giscanner/scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 119 "giscanner/scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 120 "giscanner/scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 121 "giscanner/scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 122 "giscanner/scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 123 "giscanner/scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 124 "giscanner/scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 125 "giscanner/scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 126 "giscanner/scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 127 "giscanner/scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 128 "giscanner/scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 129 "giscanner/scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 130 "giscanner/scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 131 "giscanner/scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 132 "giscanner/scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 133 "giscanner/scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 134 "giscanner/scannerlexer.l"
{ return '='; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 135 "giscanner/scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 136 "giscanner/scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 137 "giscanner/scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 138 "giscanner/scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 139 "giscanner/scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 140 "giscanner/scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 141 "giscanner/scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 142 "giscanner/scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 143 "giscanner/scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 144 "giscanner/scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 145 "giscanner/scannerlexer.l"
{ return SL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 146 "giscanner/scannerlexer.l"
{ return SR; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 147 "giscanner/scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 148 "giscanner/scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 149 "giscanner/scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 150 "giscanner/scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 151 "giscanner/scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 152 "giscanner/scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 153 "giscanner/scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 154 "giscanner/scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 155 "giscanner/scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 156 "giscanner/scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 157 "giscanner/scannerlexer.l"
{ return ','; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 158 "giscanner/scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 160 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 161 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 162 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 163 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 164 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 165 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 166 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 167 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 168 "giscanner/scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 169 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 170 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 171 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 172 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 173 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 174 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 175 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 176 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 177 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 178 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 179 "giscanner/scannerlexer.l"
{ return THREAD_LOCAL; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 180 "giscanner/scannerlexer.l"
{ return THREAD_LOCAL; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 181 "giscanner/scannerlexer.l"
{ if (parse_ignored_macro()) return VOID; else REJECT; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 182 "giscanner/scannerlexer.l"
{ if (parse_ignored_macro()) return VOID; else REJECT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 183 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 184 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 185 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
#line 186 "giscanner/scannerlexer.l"
{ ++lineno; /* Ignore */ }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 187 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 188 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 189 "giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 190 "giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 191 "giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 193 "giscanner/scannerlexer.l"
{ return INTL_CONST; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 194 "giscanner/scannerlexer.l"
{ return INTUL_CONST; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 196 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 197 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 198 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 199 "giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 201 "giscanner/scannerlexer.l"
{ if (scanner->macro_scan) return check_identifier(scanner, yytext); else REJECT; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 203 "giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 204 "giscanner/scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 205 "giscanner/scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 206 "giscanner/scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 207 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 208 "giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 209 "giscanner/scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 210 "giscanner/scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 211 "giscanner/scannerlexer.l"
{ return DO; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 212 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 213 "giscanner/scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 214 "giscanner/scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 215 "giscanner/scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 216 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 217 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 218 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 219 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 220 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 221 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 222 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 223 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 224 "giscanner/scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 225 "giscanner/scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 226 "giscanner/scannerlexer.l"
{ return IF; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 227 "giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 228 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 229 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 230 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 231 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 232 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 233 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 234 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 235 "giscanner/scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 236 "giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 237 "giscanner/scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 238 "giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 239 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 240 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 241 "giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 242 "giscanner/scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 243 "giscanner/scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 244 "giscanner/scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 245 "giscanner/scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 246 "giscanner/scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 247 "giscanner/scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 248 "giscanner/scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 249 "giscanner/scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 250 "giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 251 "giscanner/scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 253 "giscanner/scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 255 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 256 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 257 "giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 259 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 260 "giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 165:
/* rule 165 can match eol */
YY_RULE_SETUP
#line 262 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 166:
/* rule 166 can match eol */
YY_RULE_SETUP
#line 263 "giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 167:
/* rule 167 can match eol */
YY_RULE_SETUP
#line 265 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 168:
/* rule 168 can match eol */
YY_RULE_SETUP
#line 266 "giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 268 "giscanner/scannerlexer.l"
{ print_error(scanner); }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 270 "giscanner/scannerlexer.l"
ECHO;
	YY_BREAK
#line 2383 "giscanner/scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 745 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 745 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 744);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 270 "giscanner/scannerlexer.l"


static int
yywrap (void)
{
  return 1;
}

static void
parse_comment (GISourceScanner *scanner)
{
  int c1, c2;
  GString *string = NULL;
  GISourceComment *comment;
  int comment_lineno;
  int skip = FALSE;

  c1 = input();
  c2 = input();

  if (c2 != IS_EOF && (c1 == '*' && c2 != '*' && c2 != '/')) {
    /*
     * Store GTK-Doc comment blocks,
     * starts with one '/' followed by exactly two '*' and not followed by a '/'
     */
    if (!g_hash_table_contains (scanner->files, scanner->current_file)) {
        skip = TRUE;
    } else {
        string = g_string_new (yytext);
    }

    comment_lineno = lineno;

    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (!skip)
          g_string_append_c (string, c1);

        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    if (skip) {
        return;
    }

    g_string_append (string, "*/");

    comment = g_slice_new (GISourceComment);
    comment->comment = g_string_free (string, FALSE);
    comment->line = comment_lineno;
    comment->filename = g_file_get_parse_name (scanner->current_file);

    gi_source_scanner_take_comment (scanner, comment);
  } else {
    /*
     * Ignore all other comment blocks
     */
    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    return;
  }
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/* taken from glib/gfileutils.c */
#if defined(MAXPATHLEN)
#define G_PATH_LENGTH MAXPATHLEN
#elif defined(PATH_MAX)
#define G_PATH_LENGTH PATH_MAX
#elif defined(_PC_PATH_MAX)
#define G_PATH_LENGTH sysconf(_PC_PATH_MAX)
#else
#define G_PATH_LENGTH 2048
#endif

static inline char *
_realpath (const char *path)
{
#ifndef _WIN32
  char buffer[G_PATH_LENGTH];

  return realpath (path, buffer) ? g_strdup (buffer) : NULL;
#else
  /* We don't want to include <windows.h> as it clashes horribly
   * with token names from scannerparser.h. So just declare
   * GetFullPathNameA() here unless we already defined it, like
   * in giscanner.c.
   */
  extern unsigned long __stdcall GetFullPathNameA(const char*, int, char*, char**);
  char *buffer;
  char dummy;
  int rc, len;

  rc = GetFullPathNameA (path, 1, &dummy, NULL);
  if (rc == 0)
    {
      /* Weird failure, so just return the input path as such */
      return g_strdup (path);
    }

  len = rc + 1;
  buffer = g_malloc (len);

  rc = GetFullPathNameA (path, len, buffer, NULL);
  if (rc == 0 || rc > len)
    {
      /* Weird failure again */
      g_free (buffer);
      return g_strdup (path);
    }
  return buffer;
#endif
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner, gboolean has_line)
{
	char escaped_filename[1025];
	char *filename;
	char *real;

	if (has_line)
		sscanf(yytext, "#line %d \"%1024[^\"]\"", &lineno, escaped_filename);
	else
		sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);

	filename = g_strcompress (escaped_filename);

        real = _realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (scanner->current_file)
          g_object_unref (scanner->current_file);
	scanner->current_file = g_file_new_for_path (filename);
	g_free (filename);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != IS_EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != IS_EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != IS_EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

static void
print_error (GISourceScanner *scanner)
{
  if (yytext[0]) {
    char *filename = g_file_get_parse_name (scanner->current_file);
    gchar *error = g_strdup_printf ("%s:%d: unexpected character `%c'", filename, lineno, yytext[0]);
    g_ptr_array_add (scanner->errors, error);
    g_free (filename);
  }
}

